==> haskell-tasty-rerun-1.1.6-12-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-rerun.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-rerun
version: 1.1.6
id: tasty-rerun-1.1.6-BMfjKHywFVdDpWaBTFjbI
key: tasty-rerun-1.1.6-BMfjKHywFVdDpWaBTFjbI
license: BSD3
copyright: Oliver Charles (c) 2014
maintainer: ollie@ocharles.org.uk
homepage: http://github.com/ocharles/tasty-rerun
synopsis: Run tests by filtering the test tree depending on the result of previous test
          runs
description:
    This ingredient adds the ability to run tests by first filtering the test tree
    based on the result of a previous test run. For example, you can use this to
    run only those tests that failed in the last run, or to run only tests that
    have been added since tests were last ran.
    .
    This ingredient is specifically an ingredient *transformer* - given a list of
    '\''Tasty.Ingredient'\''s, '\''rerunningTests'\'' adds the ability for all of these
    ingredients to run against a filtered test tree. This transformer can be
    applied as follows:
    .
    > import Test.Tasty
    > import Test.Tasty.Runners
    >
    > main :: IO ()
    > main =
    >   defaultMainWithIngredients
    >     [ rerunningTests [ listingTests, consoleTestReporter ] ]
    >     tests
    >
    > tests :: TestTree
    > tests = undefined
    .
    This ingredient adds three command line parameters:
    .
    [@--rerun-update@] If specified the results of this test run will be saved to
    the log file at @--rerun-log-file@. If the ingredient does not execute tests
    (for example, @--list-tests@ is used) then the log file will not be
    updated. This option is not enabled by default.  This option does not require
    a value.
    .
    [@--rerun-log-file@] The path to the log file to read previous test
    information from, and where to write new information to (if @--rerun-update@
    is specified). This option defaults to @.tasty-rerun-log@.
    .
    [@--rerun-filter@] Which filters to apply to the '\''Tasty.TestTree'\'' based on
    previous test runs. The value of this option is a comma separated list of the
    following options:
    .
    * @failures@: Only run tests that failed on the previous run.
    .
    * @exceptions@: Only run tests that threw an exception on the previous run.
    .
    * @new@: Only run tests that are new since the previous test run.
    .
    * @successful@: Only run tests that were successful in the previous run.
    .
    Multiple options can be combined and will be taken under disjunction - so
    @--rerun-filter=failures,exceptions@ will run only tests that failed *or*
    threw an exception on the last run.
    .
    Defaults to all filters, which means all tests will be ran.
category: Testing
author: Oliver Charles
exposed: True
exposed-modules:
    Test.Tasty.Ingredients.Rerun
abi: 5ac8ee95ea7a8da1139aeda87f0ca0bf
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/tasty-rerun-1.1.6
library-dirs: /usr/lib/ghc-8.0.1/site-local/tasty-rerun-1.1.6
data-dir: /usr/share/arm-linux-ghc-8.0.1/tasty-rerun-1.1.6
hs-libraries: HStasty-rerun-1.1.6-BMfjKHywFVdDpWaBTFjbI
depends:
    base-4.9.0.0 containers-0.5.7.1 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    optparse-applicative-0.13.1.0-IMOgMyEFJ9R7Y6gGL71zwn
    reducers-3.12.1-2Swcb53ldVvD4253gH5RvN
    split-0.2.3.1-IJKK4pOCYGKud0jZImZke
    stm-2.4.4.1-9HlGYelGmT69YkepeDjuRg
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq
    tasty-0.11.2-6z92abaSOjx3BjdmRtWoDi transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-tasty-rerun/html/tasty-rerun.haddock
haddock-html: /usr/share/doc/haskell-tasty-rerun/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-rerun-1.1.6-13-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-rerun.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-rerun
version: 1.1.6
id: tasty-rerun-1.1.6-BB82c6ku204BFD3OgpTCw3
key: tasty-rerun-1.1.6-BB82c6ku204BFD3OgpTCw3
license: BSD3
copyright: Oliver Charles (c) 2014
maintainer: ollie@ocharles.org.uk
homepage: http://github.com/ocharles/tasty-rerun
synopsis: Run tests by filtering the test tree depending on the result of previous test
          runs
description:
    This ingredient adds the ability to run tests by first filtering the test tree
    based on the result of a previous test run. For example, you can use this to
    run only those tests that failed in the last run, or to run only tests that
    have been added since tests were last ran.
    .
    This ingredient is specifically an ingredient *transformer* - given a list of
    '\''Tasty.Ingredient'\''s, '\''rerunningTests'\'' adds the ability for all of these
    ingredients to run against a filtered test tree. This transformer can be
    applied as follows:
    .
    > import Test.Tasty
    > import Test.Tasty.Runners
    >
    > main :: IO ()
    > main =
    >   defaultMainWithIngredients
    >     [ rerunningTests [ listingTests, consoleTestReporter ] ]
    >     tests
    >
    > tests :: TestTree
    > tests = undefined
    .
    This ingredient adds three command line parameters:
    .
    [@--rerun-update@] If specified the results of this test run will be saved to
    the log file at @--rerun-log-file@. If the ingredient does not execute tests
    (for example, @--list-tests@ is used) then the log file will not be
    updated. This option is not enabled by default.  This option does not require
    a value.
    .
    [@--rerun-log-file@] The path to the log file to read previous test
    information from, and where to write new information to (if @--rerun-update@
    is specified). This option defaults to @.tasty-rerun-log@.
    .
    [@--rerun-filter@] Which filters to apply to the '\''Tasty.TestTree'\'' based on
    previous test runs. The value of this option is a comma separated list of the
    following options:
    .
    * @failures@: Only run tests that failed on the previous run.
    .
    * @exceptions@: Only run tests that threw an exception on the previous run.
    .
    * @new@: Only run tests that are new since the previous test run.
    .
    * @successful@: Only run tests that were successful in the previous run.
    .
    Multiple options can be combined and will be taken under disjunction - so
    @--rerun-filter=failures,exceptions@ will run only tests that failed *or*
    threw an exception on the last run.
    .
    Defaults to all filters, which means all tests will be ran.
category: Testing
author: Oliver Charles
exposed: True
exposed-modules:
    Test.Tasty.Ingredients.Rerun
abi: 9caa18c0a3c3080425ef5b52830dd833
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/tasty-rerun-1.1.6
library-dirs: /usr/lib/ghc-8.0.1/site-local/tasty-rerun-1.1.6
data-dir: /usr/share/arm-linux-ghc-8.0.1/tasty-rerun-1.1.6
hs-libraries: HStasty-rerun-1.1.6-BB82c6ku204BFD3OgpTCw3
depends:
    base-4.9.0.0 containers-0.5.7.1 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    optparse-applicative-0.13.2.0-403Af4vaGHEIyn0ZdeZhZL
    reducers-3.12.1-2Swcb53ldVvD4253gH5RvN
    split-0.2.3.1-IJKK4pOCYGKud0jZImZke
    stm-2.4.4.1-9HlGYelGmT69YkepeDjuRg
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq
    tasty-0.11.2-7HFEGQoIhGWF7abjUMlu0O transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-tasty-rerun/html/tasty-rerun.haddock
haddock-html: /usr/share/doc/haskell-tasty-rerun/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
